Banyan — Banyan 0.1.5 documentation

### Navigation

- index
- modules |
- next |
- Banyan 0.1.5 documentation »

# Banyan

High-Performance Augmentable Sorted Sets And Dictionaries

Contents:

- Introduction
  - Features
  - A Few Quick Examples
  - Download, Installation, Documentation, And Bugtracking
  - Changes
  - Planned Features
- Augmenting Trees
  - Introduction
  - Implementation In Banyan
  - Performance
- Performance
  - Collections
  - Methods
  - Updators
- Reference
  - Collections
  - Views
  - Node Updators

### Navigation

- index
- modules |
- next |
- Banyan 0.1.5 documentation »